@@ -11,7 +11,7 @@ def infer(img, model_pt):
     model = DeepLab(output_stride=16, num_classes=8)
     model.eval()
 
-    model.load_state_dict(torch.load(model_pt, map_location="cpu"))
+    model.load_state_dict(torch.load(model_pt))
     if torch.cuda.is_available():
         model.to(device)
 
